@@ -1,5 +1,5 @@
 from snakypy.helpers.catches import shell
-from snakypy.helpers.ansi import FG, NONE
+from snakypy.helpers import FG, printer
 from snakypy.helpers.catches import whoami
 from subprocess import call as subprocess_call
 
@@ -9,10 +9,10 @@ def reload_zsh() -> None:
 
 
 def change_shell() -> bool:
-    if shell()[0] != "zsh":
+    if shell() != "zsh":
         try:
             subprocess_call(f"chsh -s $(which zsh) {whoami()}", shell=True)
             return True
-        except KeyboardInterrupt as err:
-            raise KeyboardInterrupt(f"{FG().WARNING}Canceled by user.{NONE}", err)
+        except KeyboardInterrupt:
+            printer("Canceled by user.", foreground=FG().WARNING)
     return False
